pub struct SourceFile(/* private fields */);Expand description
A source file tracked by the Salsa incremental engine.
Each field change bumps the revision, causing dependent tracked functions to be re-evaluated on next access.
Implementations
Sourceimpl SourceFile
impl SourceFile
pub fn ingredient(db: &(dyn Database + 'static)) -> &IngredientImpl<SourceFile>
pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<SourceFile>, &mut Runtime)
Sourceimpl SourceFile
impl SourceFile
pub fn new<Db_>( db: &Db_, uri: String, text: String, encoding: PositionEncodingKind, ) -> SourceFile
pub fn builder( uri: String, text: String, encoding: PositionEncodingKind, ) -> <SourceFile as HasBuilder>::Builder
pub fn uri<'db, Db_>(self, db: &'db Db_) -> String
pub fn text<'db, Db_>(self, db: &'db Db_) -> String
pub fn encoding<'db, Db_>(self, db: &'db Db_) -> PositionEncodingKind
pub fn set_uri<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = String> + use<'db, Db_>
pub fn set_text<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = String> + use<'db, Db_>
pub fn set_encoding<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = PositionEncodingKind> + use<'db, Db_>
Sourcepub fn default_debug_fmt(
this: SourceFile,
f: &mut Formatter<'_>,
) -> Result<(), Error>where
String: for<'__trivial_bounds> Debug + for<'__trivial_bounds> Debug,
PositionEncodingKind: for<'__trivial_bounds> Debug,
pub fn default_debug_fmt(
this: SourceFile,
f: &mut Formatter<'_>,
) -> Result<(), Error>where
String: for<'__trivial_bounds> Debug + for<'__trivial_bounds> Debug,
PositionEncodingKind: for<'__trivial_bounds> Debug,
Default debug formatting for this struct (may be useful if you define your own Debug impl)