pub struct ClientBuilder {}Expand description
Builder for constructing a client connection to a Language Server.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
Sourcepub fn build<C, I, O>(self, _client: C, input: I, output: O) -> ServerHandlewhere
C: LanguageClient + Send + 'static,
I: AsyncRead + Unpin + Send + 'static,
O: AsyncWrite + Unpin + Send + 'static,
pub fn build<C, I, O>(self, _client: C, input: I, output: O) -> ServerHandlewhere
C: LanguageClient + Send + 'static,
I: AsyncRead + Unpin + Send + 'static,
O: AsyncWrite + Unpin + Send + 'static,
Build the client connection. Takes a type implementing LanguageClient
to handle inbound server messages, and the I/O streams for the transport.
input is the server’s stdout (we read responses from it).
output is the server’s stdin (we write requests to it).
Returns the ServerHandle which can be used to send outbound requests.