pub struct ServerHandle { /* private fields */ }Expand description
A handle to interact with the connected Language Server. This acts as the outbound proxy for the downstream client.
Implementations
Sourceimpl ServerHandle
impl ServerHandle
pub fn new( sender: Sender<Value>, pending: Arc<Mutex<HashMap<u64, Sender<Value>>>>, next_id: Arc<AtomicU64>, ) -> Self
Sourcepub async fn request<R>(
&self,
method: &str,
params: impl Serialize,
) -> Result<Option<R>, ClientError>where
R: DeserializeOwned,
pub async fn request<R>(
&self,
method: &str,
params: impl Serialize,
) -> Result<Option<R>, ClientError>where
R: DeserializeOwned,
Helper to send a request and await a correlated response.
pub async fn initialize( &self, params: InitializeParams, ) -> Result<InitializeResult, ClientError>
pub async fn initialized(&self, params: InitializedParams)
pub async fn shutdown(&self) -> Result<(), ClientError>
pub async fn exit(&self)
pub async fn did_open(&self, params: DidOpenTextDocumentParams)
pub async fn did_change(&self, params: DidChangeTextDocumentParams)
pub async fn did_save(&self, params: DidSaveTextDocumentParams)
pub async fn did_close(&self, params: DidCloseTextDocumentParams)
pub async fn hover( &self, params: HoverParams, ) -> Result<Option<Hover>, ClientError>
pub async fn completion( &self, params: CompletionParams, ) -> Result<Option<CompletionResponse>, ClientError>
pub async fn completion_resolve( &self, params: CompletionItem, ) -> Result<CompletionItem, ClientError>
pub async fn signature_help( &self, params: SignatureHelpParams, ) -> Result<Option<SignatureHelp>, ClientError>
pub async fn goto_definition( &self, params: GotoDefinitionParams, ) -> Result<Option<GotoDefinitionResponse>, ClientError>
pub async fn goto_declaration( &self, params: GotoDefinitionParams, ) -> Result<Option<GotoDefinitionResponse>, ClientError>
pub async fn goto_implementation( &self, params: GotoDefinitionParams, ) -> Result<Option<GotoDefinitionResponse>, ClientError>
pub async fn goto_type_definition( &self, params: GotoDefinitionParams, ) -> Result<Option<GotoDefinitionResponse>, ClientError>
pub async fn references( &self, params: ReferenceParams, ) -> Result<Option<Vec<Location>>, ClientError>
pub async fn document_highlight( &self, params: DocumentHighlightParams, ) -> Result<Option<Vec<DocumentHighlight>>, ClientError>
pub async fn document_symbol( &self, params: DocumentSymbolParams, ) -> Result<Option<DocumentSymbolResponse>, ClientError>
pub async fn code_action( &self, params: CodeActionParams, ) -> Result<Option<CodeActionResponse>, ClientError>
pub async fn code_action_resolve( &self, params: CodeAction, ) -> Result<CodeAction, ClientError>
pub async fn code_lens( &self, params: CodeLensParams, ) -> Result<Option<Vec<CodeLens>>, ClientError>
pub async fn code_lens_resolve( &self, params: CodeLens, ) -> Result<CodeLens, ClientError>
pub async fn formatting( &self, params: DocumentFormattingParams, ) -> Result<Option<Vec<TextEdit>>, ClientError>
pub async fn range_formatting( &self, params: DocumentRangeFormattingParams, ) -> Result<Option<Vec<TextEdit>>, ClientError>
pub async fn rename( &self, params: RenameParams, ) -> Result<Option<WorkspaceEdit>, ClientError>
pub async fn prepare_rename( &self, params: TextDocumentPositionParams, ) -> Result<Option<PrepareRenameResponse>, ClientError>
pub async fn semantic_tokens_full( &self, params: SemanticTokensParams, ) -> Result<Option<SemanticTokensResult>, ClientError>
pub async fn semantic_tokens_full_delta( &self, params: SemanticTokensDeltaParams, ) -> Result<Option<SemanticTokensFullDeltaResult>, ClientError>
pub async fn semantic_tokens_range( &self, params: SemanticTokensRangeParams, ) -> Result<Option<SemanticTokensRangeResult>, ClientError>
pub async fn inlay_hint( &self, params: InlayHintParams, ) -> Result<Option<Vec<InlayHint>>, ClientError>
pub async fn inlay_hint_resolve( &self, params: InlayHint, ) -> Result<InlayHint, ClientError>
pub async fn symbol( &self, params: WorkspaceSymbolParams, ) -> Result<Option<Vec<SymbolInformation>>, ClientError>
pub async fn execute_command( &self, params: ExecuteCommandParams, ) -> Result<Option<Value>, ClientError>
pub async fn did_change_configuration( &self, params: DidChangeConfigurationParams, )
pub async fn did_change_watched_files( &self, params: DidChangeWatchedFilesParams, )
pub async fn did_change_workspace_folders( &self, params: DidChangeWorkspaceFoldersParams, )