pub enum BaseProtocolMessage {
Request(RequestMessage),
Notification(NotificationMessage),
Response(ResponseMessage),
}Expand description
A wrapper enum that encapsulates all possible LSP Base Protocol 0.9 messages.
This provides a bridge between the unified Request type in lsp-max
and the explicit RequestMessage and NotificationMessage types in the LSP specification.
Variants
Request(RequestMessage)
A request message to describe a request between the client and the server.
Notification(NotificationMessage)
A notification message. A NotificationMessage works like an event and does not send a response back.
Response(ResponseMessage)
A response message is sent as a result of a request.
Implementations
Sourceimpl BaseProtocolMessage
impl BaseProtocolMessage
Sourcepub fn from_request(request: Request) -> Self
pub fn from_request(request: Request) -> Self
Converts a lsp-max Request into a BaseProtocolMessage.
This will be either a Request or a Notification depending on whether an ID is present.
Sourcepub fn from_response(response: Response) -> Self
pub fn from_response(response: Response) -> Self
Converts a lsp-max Response into a BaseProtocolMessage.