Error

Struct Error 

pub struct Error {
    pub code: ErrorCode,
    pub message: Cow<'static, str>,
    pub data: Option<Value>,
}
A JSON-RPC error object.

Fields

code: ErrorCode

A number indicating the error type that occurred.

message: Cow<'static, str>

A short description of the error.

data: Option<Value>

Additional information about the error, if any.

Implementations

Source

impl Error

pub const fn new(code: ErrorCode) -> Self

Creates a new error from the given ErrorCode.

pub const fn parse_error() -> Self

Creates a new parse error (-32700).

pub const fn invalid_request() -> Self

Creates a new “invalid request” error (-32600).

pub const fn method_not_found() -> Self

Creates a new “method not found” error (-32601).

pub fn invalid_params<M>(message: M) -> Self
where M: Into<Cow<'static, str>>,

Creates a new “invalid params” error (-32602).

pub const fn internal_error() -> Self

Creates a new internal error (-32603).

pub const fn server_not_initialized() -> Self

Creates a new “server not initialized” error (-32002).

Compatibility

This error code is defined by the Language Server Protocol.

pub const fn request_cancelled() -> Self

Creates a new “request cancelled” error (-32800).

Compatibility

This error code is defined by the Language Server Protocol.

pub const fn content_modified() -> Self

Creates a new “content modified” error (-32801).

Compatibility

This error code is defined by the Language Server Protocol.

pub const fn server_cancelled() -> Self

Creates a new “server cancelled” error (-32802).

Compatibility

This error code is defined by the Language Server Protocol.

pub fn request_failed<M>(message: M) -> Self
where M: Into<Cow<'static, str>>,

Creates a new “request failed” server error (-32803).

Used to propagate runtime dispatch failures from the autonomic mesh.