pub struct Response { /* private fields */ }Expand description
A successful or failed JSON-RPC response.
Implementations
Sourceimpl Response
impl Response
Sourcepub const fn from_ok(id: Id, result: Value) -> Self
pub const fn from_ok(id: Id, result: Value) -> Self
Creates a new successful response from a request ID and Error object.
Sourcepub const fn from_error(id: Id, error: Error) -> Self
pub const fn from_error(id: Id, error: Error) -> Self
Creates a new error response from a request ID and Error object.
Sourcepub fn from_parts(id: Id, body: Result<Value>) -> Self
pub fn from_parts(id: Id, body: Result<Value>) -> Self
Creates a new response from a request ID and either an Ok(Value) or Err(Error) body.
Sourcepub fn into_parts(self) -> (Id, Result<Value>)
pub fn into_parts(self) -> (Id, Result<Value>)
Splits the response into a request ID paired with either an Ok(Value) or Err(Error) to
signify whether the response is a success or failure.
Sourcepub const fn result(&self) -> Option<&Value>
pub const fn result(&self) -> Option<&Value>
Returns the result value, if it exists.
This member only exists if the response indicates success.
Sourcepub const fn error(&self) -> Option<&Error>
pub const fn error(&self) -> Option<&Error>
Returns the error value, if it exists.
This member only exists if the response indicates failure.
Sourcepub fn from_message(msg: ResponseMessage) -> Self
pub fn from_message(msg: ResponseMessage) -> Self
Constructs a JSON-RPC response from an lsp_types_max::ResponseMessage.