pub struct Keystore { /* private fields */ }Expand description
A robust Key Management Keystore for Ed25519 signing and verification.
Implementations
Sourceimpl Keystore
impl Keystore
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Self, KeyManagementError>
pub fn from_bytes(bytes: &[u8]) -> Result<Self, KeyManagementError>
Create from a seed slice.
Sourcepub fn load_from_file<P: AsRef<Path>>(
path: P,
) -> Result<Self, KeyManagementError>
pub fn load_from_file<P: AsRef<Path>>( path: P, ) -> Result<Self, KeyManagementError>
Load primary key from file containing raw 32 seed bytes.
Sourcepub fn save_to_file<P: AsRef<Path>>(
&self,
path: P,
) -> Result<(), KeyManagementError>
pub fn save_to_file<P: AsRef<Path>>( &self, path: P, ) -> Result<(), KeyManagementError>
Save primary key seed to file.
Sourcepub fn verifying_key(&self) -> VerifyingKey
pub fn verifying_key(&self) -> VerifyingKey
Returns the VerifyingKey of the primary key pair.
Sourcepub fn sign_hash(&self, hash: &Blake3Hash) -> [u8; 64]
pub fn sign_hash(&self, hash: &Blake3Hash) -> [u8; 64]
Sign a payload hash using the primary key.
Sourcepub fn sign_receipt(&self, receipt: &mut CryptographicReceipt)
pub fn sign_receipt(&self, receipt: &mut CryptographicReceipt)
Sign a CryptographicReceipt in place using the primary key.
Sourcepub fn register_trusted_key(&self, id: Uuid, key: VerifyingKey)
pub fn register_trusted_key(&self, id: Uuid, key: VerifyingKey)
Register a trusted verifying public key associated with a Uuid.
Sourcepub fn get_trusted_key(&self, id: &Uuid) -> Option<VerifyingKey>
pub fn get_trusted_key(&self, id: &Uuid) -> Option<VerifyingKey>
Retrieve a trusted verifying public key.
Sourcepub fn verify_signature(
verifying_key: &VerifyingKey,
hash: &Blake3Hash,
signature_bytes: &[u8; 64],
) -> Result<(), KeyManagementError>
pub fn verify_signature( verifying_key: &VerifyingKey, hash: &Blake3Hash, signature_bytes: &[u8; 64], ) -> Result<(), KeyManagementError>
Verify a signature against a payload hash.
Sourcepub fn verify_receipt(
&self,
receipt: &CryptographicReceipt,
) -> Result<(), KeyManagementError>
pub fn verify_receipt( &self, receipt: &CryptographicReceipt, ) -> Result<(), KeyManagementError>
Verify a CryptographicReceipt’s signature using the verifying key registered for its discipline_id, or fallback to the primary verifying key if no specific key is registered.