pub struct Machine<L: Law, P: Phase, D: Data> {
pub _law: PhantomData<L>,
pub phase: P,
pub data: D,
}Expand description
The zero-cost typestate machine container.
Fields
_law: PhantomData<L>phase: Pdata: DImplementations
Sourceimpl Machine<AccessAdmissionLaw, Uninitialized, EmptyData>
impl Machine<AccessAdmissionLaw, Uninitialized, EmptyData>
Sourcepub fn admit_initialize(
self,
client_caps: Value,
) -> Machine<AccessAdmissionLaw, Initializing, InitializingData>
pub fn admit_initialize( self, client_caps: Value, ) -> Machine<AccessAdmissionLaw, Initializing, InitializingData>
Transitions from Uninitialized to Initializing using the client parameters.
Sourceimpl Machine<AccessAdmissionLaw, Initializing, InitializingData>
impl Machine<AccessAdmissionLaw, Initializing, InitializingData>
Sourcepub fn admit_initialized(
self,
server_caps: Value,
) -> Machine<AccessAdmissionLaw, Initialized, InitializedData>
pub fn admit_initialized( self, server_caps: Value, ) -> Machine<AccessAdmissionLaw, Initialized, InitializedData>
Transitions from Initializing to Initialized once server capabilities are registered.
Sourceimpl Machine<AccessAdmissionLaw, Initialized, InitializedData>
impl Machine<AccessAdmissionLaw, Initialized, InitializedData>
Sourcepub fn admit_shutdown(self) -> Machine<AccessAdmissionLaw, ShutDown, EmptyData>
pub fn admit_shutdown(self) -> Machine<AccessAdmissionLaw, ShutDown, EmptyData>
Transitions from Initialized to ShutDown.
Sourceimpl Machine<AccessAdmissionLaw, ShutDown, EmptyData>
impl Machine<AccessAdmissionLaw, ShutDown, EmptyData>
Sourcepub fn admit_exit(self) -> Machine<AccessAdmissionLaw, Exited, EmptyData>
pub fn admit_exit(self) -> Machine<AccessAdmissionLaw, Exited, EmptyData>
Transitions from ShutDown to Exited.
Sourceimpl Machine<GraphAdmissionLaw, RAW, RawData>
impl Machine<GraphAdmissionLaw, RAW, RawData>
pub fn admit_candidate( self, snapshot_id: &str, ) -> Result<Machine<GraphAdmissionLaw, CANDIDATE, CandidateData>, GraphAdmissionError>
Sourceimpl Machine<GraphAdmissionLaw, CANDIDATE, CandidateData>
impl Machine<GraphAdmissionLaw, CANDIDATE, CandidateData>
pub fn admit_admitted( self, _store: &Store, graph_name: GraphName, receipt: CryptographicReceipt, ) -> Result<Machine<GraphAdmissionLaw, ADMITTED, AdmittedData>, GraphAdmissionError>
pub fn admit_refuse( self, report: VerificationReport, ) -> Machine<GraphAdmissionLaw, REFUSED, RefusedData>
pub fn admit_quarantine( self, missing_dependencies: Vec<String>, ) -> Machine<GraphAdmissionLaw, QUARANTINED, QuarantinedData>
pub fn admit_replay( self, graph_name: GraphName, receipt: CryptographicReceipt, ) -> Machine<GraphAdmissionLaw, REPLAYED, ReplayedData>
Sourceimpl Machine<GraphAdmissionLaw, ADMITTED, AdmittedData>
impl Machine<GraphAdmissionLaw, ADMITTED, AdmittedData>
pub fn admit_supersede( self, superseded_by: GraphName, ) -> Machine<GraphAdmissionLaw, SUPERSEDED, SupersededData>
Sourceimpl Machine<GraphAdmissionLaw, QUARANTINED, QuarantinedData>
impl Machine<GraphAdmissionLaw, QUARANTINED, QuarantinedData>
pub fn into_candidate( self, graph_hash: String, ) -> Machine<GraphAdmissionLaw, CANDIDATE, CandidateData>