pub struct Pending(/* private fields */);Expand description
A hashmap containing pending server requests, keyed by request ID.
Implementations
Sourceimpl Pending
impl Pending
Sourcepub fn execute<F>(
&self,
id: Id,
fut: F,
) -> impl Future<Output = Result<Option<Response>, ExitedError>> + Send + 'static
pub fn execute<F>( &self, id: Id, fut: F, ) -> impl Future<Output = Result<Option<Response>, ExitedError>> + Send + 'static
Executes the given async request handler, keyed by the given request ID.
If a cancel request is issued before the future is finished resolving, this will resolve to a “canceled” error response, and the pending request handler future will be dropped.
Sourcepub fn cancel(&self, id: &Id)
pub fn cancel(&self, id: &Id)
Attempts to cancel the running request handler corresponding to this ID.
This will force the future to resolve to a “canceled” error response. If the future has already completed, this method call will do nothing.
Sourcepub fn cancel_all(&self)
pub fn cancel_all(&self)
Cancels all pending request handlers, if any.