pub struct ServerState {
pub mesh: Mutex<AutonomicMesh>,
/* private fields */
}Expand description
Thread-safe server state wrapper using a mutex.
Fields
mesh: Mutex<AutonomicMesh>The autonomic mesh manager for monitoring the workspace state.
Implementations
Sourceimpl ServerState
impl ServerState
Sourcepub fn set(&self, state: State)
pub fn set(&self, state: State)
Set the server state explicitly, discarding previous typestate data. This is provided for compatibility and direct overrides.
Sourcepub fn set_exit_code(&self, code: i32)
pub fn set_exit_code(&self, code: i32)
Sets the exit code.
Sourcepub fn get_exit_code(&self) -> i32
pub fn get_exit_code(&self) -> i32
Gets the exit code.
Sourcepub fn set_parent_pid(&self, pid: u32)
pub fn set_parent_pid(&self, pid: u32)
Sets the parent process ID.
Sourcepub fn get_parent_pid(&self) -> Option<u32>
pub fn get_parent_pid(&self) -> Option<u32>
Gets the parent process ID.
Sourcepub fn try_initialize(&self, client_caps: Value) -> bool
pub fn try_initialize(&self, client_caps: Value) -> bool
Attempts to transition from Uninitialized to Initializing phase.
Sourcepub fn transition_to_initialized(&self, server_caps: Value) -> bool
pub fn transition_to_initialized(&self, server_caps: Value) -> bool
Transitions from Initializing to Initialized phase.
Sourcepub fn transition_to_uninitialized(&self) -> bool
pub fn transition_to_uninitialized(&self) -> bool
Reverts transition back to Uninitialized from Initializing phase.
Sourcepub fn transition_to_shutdown(&self) -> bool
pub fn transition_to_shutdown(&self) -> bool
Transitions from Initialized to ShutDown phase.
Sourcepub fn transition_to_exited(&self) -> bool
pub fn transition_to_exited(&self) -> bool
Transitions to Exited phase.
Sourcepub fn poll_initializing(&self, cx: &mut Context<'_>) -> Poll<()>
pub fn poll_initializing(&self, cx: &mut Context<'_>) -> Poll<()>
Polls whether the server state is currently Initializing.
If yes, registers the waker to be notified when state changes.