pub struct Error {
pub code: ErrorCode,
pub message: Cow<'static, str>,
pub data: Option<Value>,
}Expand description
A JSON-RPC error object.
Fields
code: ErrorCodeA number indicating the error type that occurred.
message: Cow<'static, str>A short description of the error.
data: Option<Value>Additional information about the error, if any.
Implementations
Sourceimpl Error
impl Error
Sourcepub const fn parse_error() -> Self
pub const fn parse_error() -> Self
Creates a new parse error (-32700).
Sourcepub const fn invalid_request() -> Self
pub const fn invalid_request() -> Self
Creates a new “invalid request” error (-32600).
Sourcepub const fn method_not_found() -> Self
pub const fn method_not_found() -> Self
Creates a new “method not found” error (-32601).
Sourcepub fn invalid_params<M>(message: M) -> Self
pub fn invalid_params<M>(message: M) -> Self
Creates a new “invalid params” error (-32602).
Sourcepub const fn internal_error() -> Self
pub const fn internal_error() -> Self
Creates a new internal error (-32603).
Sourcepub const fn server_not_initialized() -> Self
pub const fn server_not_initialized() -> Self
Creates a new “server not initialized” error (-32002).
Compatibility
This error code is defined by the Language Server Protocol.
Sourcepub const fn request_cancelled() -> Self
pub const fn request_cancelled() -> Self
Creates a new “request cancelled” error (-32800).
Compatibility
This error code is defined by the Language Server Protocol.
Sourcepub const fn content_modified() -> Self
pub const fn content_modified() -> Self
Creates a new “content modified” error (-32801).
Compatibility
This error code is defined by the Language Server Protocol.
Sourcepub const fn server_cancelled() -> Self
pub const fn server_cancelled() -> Self
Creates a new “server cancelled” error (-32802).
Compatibility
This error code is defined by the Language Server Protocol.
Sourcepub fn request_failed<M>(message: M) -> Self
pub fn request_failed<M>(message: M) -> Self
Creates a new “request failed” server error (-32803).
Used to propagate runtime dispatch failures from the autonomic mesh.