pub struct Client { /* private fields */ }Expand description
Handle for communicating with the language client.
Implementations
Sourceimpl Client
impl Client
Sourcepub async fn register_capability(
&self,
registrations: Vec<Registration>,
) -> Result<()>
pub async fn register_capability( &self, registrations: Vec<Registration>, ) -> Result<()>
Registers a new capability with the client.
This corresponds to the client/registerCapability request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Sourcepub async fn unregister_capability(
&self,
unregisterations: Vec<Unregistration>,
) -> Result<()>
pub async fn unregister_capability( &self, unregisterations: Vec<Unregistration>, ) -> Result<()>
Unregisters a capability with the client.
This corresponds to the client/unregisterCapability request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Sourcepub async fn show_message<M: Display>(&self, typ: MessageType, message: M)
pub async fn show_message<M: Display>(&self, typ: MessageType, message: M)
Notifies the client to display a particular message in the user interface.
This corresponds to the window/showMessage notification.
Sourcepub async fn show_message_request<M: Display>(
&self,
typ: MessageType,
message: M,
actions: Option<Vec<MessageActionItem>>,
) -> Result<Option<MessageActionItem>>
pub async fn show_message_request<M: Display>( &self, typ: MessageType, message: M, actions: Option<Vec<MessageActionItem>>, ) -> Result<Option<MessageActionItem>>
Requests the client to display a particular message in the user interface.
Unlike the show_message notification, this request can also pass a list of actions and
wait for an answer from the client.
This corresponds to the window/showMessageRequest request.
Sourcepub async fn log_message<M: Display>(&self, typ: MessageType, message: M)
pub async fn log_message<M: Display>(&self, typ: MessageType, message: M)
Notifies the client to log a particular message.
This corresponds to the window/logMessage notification.
Sourcepub async fn log_trace(&self, params: LogTraceParams)
pub async fn log_trace(&self, params: LogTraceParams)
Notifies the client to log a trace.
This corresponds to the $/logTrace notification.
Sourcepub async fn show_document(&self, params: ShowDocumentParams) -> Result<bool>
pub async fn show_document(&self, params: ShowDocumentParams) -> Result<bool>
Asks the client to display a particular resource referenced by a URI in the user interface.
Returns Ok(true) if the document was successfully shown, or Ok(false) otherwise.
This corresponds to the window/showDocument request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.16.0.
Sourcepub async fn work_done_progress_create(
&self,
params: WorkDoneProgressCreateParams,
) -> Result<()>
pub async fn work_done_progress_create( &self, params: WorkDoneProgressCreateParams, ) -> Result<()>
Asks the client to create a work done progress token.
This corresponds to the window/workDoneProgress/create request.
Compatibility
This request was introduced in specification version 3.15.0.
Sourcepub async fn telemetry_event<S: Serialize>(&self, data: S)
pub async fn telemetry_event<S: Serialize>(&self, data: S)
Notifies the client to log a telemetry event.
This corresponds to the telemetry/event notification.
Sourcepub async fn code_lens_refresh(&self) -> Result<()>
pub async fn code_lens_refresh(&self) -> Result<()>
Asks the client to refresh the code lenses currently shown in editors. As a result, the client should ask the server to recompute the code lenses for these editors.
This is useful if a server detects a configuration change which requires a re-calculation of all code lenses.
Note that the client still has the freedom to delay the re-calculation of the code lenses if for example an editor is currently not visible.
This corresponds to the workspace/codeLens/refresh request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.16.0.
Sourcepub async fn semantic_tokens_refresh(&self) -> Result<()>
pub async fn semantic_tokens_refresh(&self) -> Result<()>
Asks the client to refresh the editors for which this server provides semantic tokens. As a result, the client should ask the server to recompute the semantic tokens for these editors.
This is useful if a server detects a project-wide configuration change which requires a re-calculation of all semantic tokens. Note that the client still has the freedom to delay the re-calculation of the semantic tokens if for example an editor is currently not visible.
This corresponds to the workspace/semanticTokens/refresh request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.16.0.
Sourcepub async fn inline_value_refresh(&self) -> Result<()>
pub async fn inline_value_refresh(&self) -> Result<()>
Asks the client to refresh the inline values currently shown in editors. As a result, the client should ask the server to recompute the inline values for these editors.
This is useful if a server detects a configuration change which requires a re-calculation of all inline values. Note that the client still has the freedom to delay the re-calculation of the inline values if for example an editor is currently not visible.
This corresponds to the workspace/inlineValue/refresh request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.17.0.
Sourcepub async fn inlay_hint_refresh(&self) -> Result<()>
pub async fn inlay_hint_refresh(&self) -> Result<()>
Asks the client to refresh the inlay hints currently shown in editors. As a result, the client should ask the server to recompute the inlay hints for these editors.
This is useful if a server detects a configuration change which requires a re-calculation of all inlay hints. Note that the client still has the freedom to delay the re-calculation of the inlay hints if for example an editor is currently not visible.
This corresponds to the workspace/inlayHint/refresh request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.17.0.
Sourcepub async fn folding_range_refresh(&self) -> Result<()>
pub async fn folding_range_refresh(&self) -> Result<()>
Asks the client to refresh all folding ranges.
This corresponds to the workspace/foldingRange/refresh request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.18.0.
Sourcepub async fn workspace_diagnostic_refresh(&self) -> Result<()>
pub async fn workspace_diagnostic_refresh(&self) -> Result<()>
Asks the client to refresh all needed document and workspace diagnostics.
This is useful if a server detects a project wide configuration change which requires a re-calculation of all diagnostics.
This corresponds to the workspace/diagnostic/refresh request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.17.0.
Sourcepub async fn text_document_content_refresh(
&self,
params: TextDocumentContentRefreshParams,
) -> Result<()>
pub async fn text_document_content_refresh( &self, params: TextDocumentContentRefreshParams, ) -> Result<()>
Asks the client to refresh the content of a text document.
This corresponds to the workspace/textDocumentContent/refresh request.
Sourcepub async fn publish_diagnostics(
&self,
uri: Uri,
diags: Vec<Diagnostic>,
version: Option<i32>,
)
pub async fn publish_diagnostics( &self, uri: Uri, diags: Vec<Diagnostic>, version: Option<i32>, )
Submits validation diagnostics for an open file with the given URI.
This corresponds to the textDocument/publishDiagnostics notification.
Initialization
This notification will only be sent if the server is initialized.
Sourcepub async fn andon_raised(&self, event: AndonEvent)
pub async fn andon_raised(&self, event: AndonEvent)
lspMax/andonRaised notification
Sourcepub async fn admission_changed(&self, status: String)
pub async fn admission_changed(&self, status: String)
lspMax/admissionChanged notification
Sourcepub async fn truth_table_changed(&self, uri: String)
pub async fn truth_table_changed(&self, uri: String)
lspMax/truthTableChanged notification
Sourcepub async fn counterfactual_failed(&self, invariant_id: String)
pub async fn counterfactual_failed(&self, invariant_id: String)
lspMax/counterfactualFailed notification
Sourcepub async fn next_lawful_step_changed(&self, step: String)
pub async fn next_lawful_step_changed(&self, step: String)
lspMax/nextLawfulStepChanged notification
Sourcepub async fn configuration(
&self,
items: Vec<ConfigurationItem>,
) -> Result<Vec<Value>>
pub async fn configuration( &self, items: Vec<ConfigurationItem>, ) -> Result<Vec<Value>>
Fetches configuration settings from the client.
The request can fetch several configuration settings in one roundtrip. The order of the
returned configuration settings correspond to the order of the passed
ConfigurationItems (e.g. the first item in the response is the result for the first
configuration item in the params).
This corresponds to the workspace/configuration request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.6.0.
Sourcepub async fn workspace_folders(&self) -> Result<Option<Vec<WorkspaceFolder>>>
pub async fn workspace_folders(&self) -> Result<Option<Vec<WorkspaceFolder>>>
Fetches the current open list of workspace folders.
Returns None if only a single file is open in the tool. Returns an empty Vec if a
workspace is open but no folders are configured.
This corresponds to the workspace/workspaceFolders request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Compatibility
This request was introduced in specification version 3.6.0.
Sourcepub async fn apply_edit(
&self,
edit: WorkspaceEdit,
) -> Result<ApplyWorkspaceEditResponse>
pub async fn apply_edit( &self, edit: WorkspaceEdit, ) -> Result<ApplyWorkspaceEditResponse>
Requests a workspace resource be edited on the client side and returns whether the edit was applied.
This corresponds to the workspace/applyEdit request.
Initialization
If the request is sent to the client before the server has been initialized, this will
immediately return Err with JSON-RPC error code -32002 (read more).
Sourcepub fn progress<T>(&self, token: ProgressToken, title: T) -> Progress
pub fn progress<T>(&self, token: ProgressToken, title: T) -> Progress
Starts a stream of $/progress notifications for a client-provided ProgressToken.
This method also takes a title argument briefly describing the kind of operation being
performed, e.g. “Indexing” or “Linking Dependencies”.
Initialization
These notifications will only be sent if the server is initialized.
Sourceimpl Client
impl Client
Sourcepub async fn cancel_request(&self, id: NumberOrString)
pub async fn cancel_request(&self, id: NumberOrString)
Sends a $/cancelRequest notification to the client.
This notification is sent from the server to the client to cancel a specific request previously sent by the server.
Initialization
This notification will only be sent if the server is initialized.
Sourcepub async fn work_done_progress_cancel(&self, token: ProgressToken)
pub async fn work_done_progress_cancel(&self, token: ProgressToken)
Sends a window/workDoneProgress/cancel notification to the client.
This notification is sent from the server to the client to inform it that the server has cancelled a specific work done progress.
Initialization
This notification will only be sent if the server is initialized.
Sourcepub async fn set_trace(&self, value: TraceValue)
pub async fn set_trace(&self, value: TraceValue)
Sends a $/setTrace notification to the client.
This notification is used to modify the trace setting of the client.
Initialization
This notification will only be sent if the server is initialized.
Sourceimpl Client
impl Client
Sourcepub async fn send_notification<N>(&self, params: N::Params)where
N: Notification,
pub async fn send_notification<N>(&self, params: N::Params)where
N: Notification,
Sends a custom notification to the client.