pub struct LspService<S> { /* private fields */ }Expand description
Service abstraction for the Language Server Protocol.
This service takes an incoming JSON-RPC message as input and produces an outgoing message as
output. If the incoming message is a server notification or a client response, then the
corresponding response will be None.
This implements tower::Service in order to remain independent from the underlying transport
and to facilitate further abstraction with middleware.
Pending requests can be canceled by issuing a $/cancelRequest notification.
The service shuts down and stops serving requests after the exit notification is received.
Implementations
Sourceimpl<S: LanguageServer> LspService<S>
impl<S: LanguageServer> LspService<S>
Sourcepub fn new<F>(init: F) -> (Self, ClientSocket)
pub fn new<F>(init: F) -> (Self, ClientSocket)
Creates a new LspService with the given server backend, also returning a channel for
server-to-client communication.
Sourcepub fn build<F>(init: F) -> LspServiceBuilder<S>
pub fn build<F>(init: F) -> LspServiceBuilder<S>
Starts building a new LspService.
Returns an LspServiceBuilder, which allows adding custom JSON-RPC methods to the server.